###################################################
### chunk number 1: 
###################################################
options(prompt= "R> ", useFancyQuotes = FALSE)


###################################################
### chunk number 2: 
###################################################
library("mlogit")


###################################################
### chunk number 3: 
###################################################
data("Fishing", package = "mlogit")
head(Fishing, 3)


###################################################
### chunk number 4: 
###################################################
data("TravelMode", package="AER")
head(TravelMode)


###################################################
### chunk number 5: 
###################################################
Fish <- mlogit.data(Fishing, shape="wide", varying=2:9, choice="mode")


###################################################
### chunk number 6: 
###################################################
head(Fish, 5)


###################################################
### chunk number 7: 
###################################################
head(index(Fish))


###################################################
### chunk number 8: 
###################################################
TM <- mlogit.data(TravelMode,
choice = "choice", shape = "long", alt.levels = c("air", "train",
"bus", "car"))


###################################################
### chunk number 9: 
###################################################
TM <- mlogit.data(TravelMode ,choice = "choice", shape = "long",
                  alt.var = "mode")


###################################################
### chunk number 10: 
###################################################
TM <- mlogit.data(TravelMode, choice = "choice",
                  shape = "long", chid.var = "individual",
                  alt.levels = c("air", "train", "bus", "car"))


###################################################
### chunk number 11: 
###################################################
TM <- mlogit.data(TravelMode, choice = "choice", shape = "long",
                 chid.var = "individual", alt.var = "mode")


###################################################
### chunk number 12: 
###################################################
TM <- mlogit.data(TravelMode, choice = "choice", shape = "long",
                 chid.var = "individual", alt.var = "mode", drop.index = TRUE)
head(TM)


###################################################
### chunk number 13: 
###################################################
data("Train", package="mlogit")
head(Train, 3)


###################################################
### chunk number 14: 
###################################################
Tr <- mlogit.data(Train, shape = 'wide', choice="choice", 
                  varying=4:11, sep="", alt.levels=c(1, 2), id = "id")
head(Tr, 3)
head(index(Tr), 3)


###################################################
### chunk number 15: 
###################################################
f <- mFormula(choice ~ vcost | income + size | travel)


###################################################
### chunk number 16: 
###################################################
f2 <- mFormula(choice ~ vcost + travel | income + size)
f2 <- mFormula(choice ~ vcost + travel | income + size | 0)


###################################################
### chunk number 17: 
###################################################
f3 <- mFormula(choice ~ 0 | income | 0)
f3 <- mFormula(choice ~ 0 | income)


###################################################
### chunk number 18: 
###################################################
f4 <- mFormula(choice ~ vcost + travel)
f4 <- mFormula(choice ~ vcost + travel | 1)
f4 <- mFormula(choice ~ vcost + travel | 1 | 0)


###################################################
### chunk number 19: 
###################################################
f5 <- mFormula(choice ~ vcost | 0 | travel)
f6 <- mFormula(choice ~ vcost | income + 0 | travel)
f6 <- mFormula(choice ~ vcost | income -1 | travel)
f7 <- mFormula(choice ~ 0 | income -1 | travel)


###################################################
### chunk number 20: 
###################################################
f <- mFormula(choice ~ vcost | income  | travel)
head(model.matrix(f, TM))


###################################################
### chunk number 21: 
###################################################
data("Train", package="mlogit")
Tr <- mlogit.data(Train, shape = 'wide', choice="choice", 
                  varying=4:11, sep="", alt.levels=c(1, 2), id = "id")



###################################################
### chunk number 22: 
###################################################
Tr$price <- Tr$price / 100 * 2.20371
Tr$time <- Tr$time / 60


###################################################
### chunk number 23: 
###################################################
ml.Train <- mlogit(choice~price+time+change+comfort | -1, Tr)
summary(ml.Train)


###################################################
### chunk number 24: 
###################################################
coef(ml.Train)[-1]/coef(ml.Train)[1]


###################################################
### chunk number 25: 
###################################################
Fish <- mlogit.data(Fishing, shape="wide", varying=2:9, choice="mode")
ml.Fish <- mlogit(mode~price | income | catch, Fish)


###################################################
### chunk number 26: 
###################################################
ml.Fish <- mlogit(mode~price | income | catch, Fishing, shape = "wide", varying = 2:9)
summary(ml.Fish)


###################################################
### chunk number 27: 
###################################################
head(fitted(ml.Fish))
head(fitted(ml.Fish, outcome=FALSE))


###################################################
### chunk number 28: 
###################################################
mlogit(mode~price | income | catch, Fish, reflevel='charter', 
       alt.subset=c('beach', 'pier', 'charter'))


###################################################
### chunk number 29: 
###################################################
data("ModeCanada", package = "mlogit")


###################################################
### chunk number 30: 
###################################################
busUsers <- with(ModeCanada, case[choice == 1 & alt == 'bus'])
Bhat <- subset(ModeCanada, !case %in% busUsers & alt != 'bus' & nchoice == 4)
Bhat$alt <- Bhat$alt[drop = TRUE]
Bhat <- mlogit.data(Bhat, shape='long', chid.var = 'case',
                    alt.var = 'alt', choice='choice',
                    drop.index=TRUE)



###################################################
### chunk number 31: 
###################################################
ml.MC <- mlogit(choice ~ freq + cost + ivt + ovt | urban + income, Bhat, reflevel = 'car')
hl.MC <- mlogit(choice ~ freq + cost + ivt + ovt | urban + income, Bhat, reflevel = 'car', heterosc = TRUE)
summary(hl.MC)


###################################################
### chunk number 32: 
###################################################
data("TravelMode",package="AER")
TravelMode <- mlogit.data(TravelMode,choice="choice",shape="long",
                          alt.var="mode",chid.var="individual")
TravelMode$avinc <- with(TravelMode,(mode=='air')*income)
ml.TM <- mlogit(choice ~ wait + gcost + avinc, TravelMode, 
                reflevel = "car")
hl.TM <- mlogit(choice ~ wait + gcost + avinc, TravelMode, 
             reflevel = "car", heterosc = TRUE)
summary(hl.TM)


###################################################
### chunk number 33: 
###################################################
c(coef(hl.TM)[7:9], sp.car = 1)*pi/sqrt(6)


###################################################
### chunk number 34: 
###################################################
data("TravelMode",package="AER")
TravelMode <- mlogit.data(TravelMode,choice="choice",shape="long",
                          alt.var="mode",chid.var="individual")
TravelMode$avinc <- with(TravelMode,(mode=='air')*income)
nl.TM <- mlogit(choice ~ wait + gcost + avinc, TravelMode, reflevel = "car", 
                nests = list(fly = "air", ground = c("train", "bus", "car")), 
                unscaled=TRUE)
summary(nl.TM)


###################################################
### chunk number 35: 
###################################################
data("HC", package = "mlogit")
HC <- mlogit.data(HC, varying = c(2:8, 10:16), choice = "depvar", shape = "wide")
head(HC)


###################################################
### chunk number 36: 
###################################################
cooling.modes <- HC$alt %in% c("gcc", "ecc", "erc","hpc")
HC$icca[!cooling.modes] <- HC$occa[!cooling.modes] <- 0


###################################################
### chunk number 37: 
###################################################
ml.HC <- mlogit(depvar~occa+icca+och+ich, HC)
nl.HC <- mlogit(depvar~occa+icca+och+ich, HC, 
                nests = list(cooling = c('ecc', 'erc', 'gcc', 'hpc'), 
                  noncool = c('ec', 'gc', 'er')))
summary(nl.HC)


###################################################
### chunk number 38: 
###################################################
nl.HC.u <- update(nl.HC, un.nest.el = TRUE)


###################################################
### chunk number 39: 
###################################################
pcl <- mlogit(choice~freq+cost+ivt+ovt, Bhat, reflevel='car',
              nests='pcl', constPar=c('iv_train_air'))
summary(pcl)


###################################################
### chunk number 40: 
###################################################
data("Train", package = "mlogit")
Tr <- mlogit.data(Train, shape = "wide", varying = 4:11, 
                  choice = "choice", sep = "", 
                  opposite = c("price", "time", "change", "comfort"),
                  alt.levels=c("choice1", "choice2"), id="id")


###################################################
### chunk number 41:  eval=FALSE
###################################################
## Train.ml <- mlogit(choice ~ price + time + change + comfort, Tr)
## Train.mxlc <- mlogit(choice ~ price + time + change + comfort, Tr,
##                panel = TRUE, rpar = c(time = "cn", change = "n", comfort = "ln"),
##                correlation = TRUE, R = 100, halton = NA)
## Train.mxlu <- update(Train.mxlc, correlation = FALSE)


###################################################
### chunk number 42: 
###################################################
data("MixedExamples", package = "mlogit")


###################################################
### chunk number 43: 
###################################################
time.value <- rpar(Train.mxlc, "time", norm = "price")
summary(time.value)
med(time.value)
mean(time.value)
stdev(time.value)


###################################################
### chunk number 44: 
###################################################
cor.mlogit(Train.mxlc)
cov.mlogit(Train.mxlc)
stdev(Train.mxlc)


###################################################
### chunk number 45: 
###################################################
ml.Fish <- mlogit(mode~price | income | catch, Fishing, shape = "wide", varying = 2:9)


###################################################
### chunk number 46: 
###################################################
ml.Fish.c <- update(ml.Fish, . ~ . | . - income | .)


###################################################
### chunk number 47: 
###################################################
waldtest(ml.Fish, ml.Fish.c)
lrtest(ml.Fish, ml.Fish.c)
scoretest(ml.Fish.c, ml.Fish)


###################################################
### chunk number 48:  eval=FALSE
###################################################
## lrtest(ml.Fish, . ~ . | . - income | .)
## lrtest(ml.Fish, mode ~ price | 1 | catch)
## lrtest(ml.Fish.c, . ~ . | . + income | .)
## lrtest(ml.Fish.c, mode ~ price | income | catch)
## waldtest(ml.Fish, . ~ . | . - income | .)
## waldtest(ml.Fish, mode ~ price | 1 | catch)
## waldtest(ml.Fish.c, . ~ . | . + income | .)
## waldtest(ml.Fish.c, mode ~ price | income | catch)
## scoretest(ml.Fish.c, . ~ . | . + income | .)
## scoretest(ml.Fish.c, mode ~ price | income | catch)


###################################################
### chunk number 49: 
###################################################
lrtest(hl.MC, ml.MC)
waldtest(hl.MC, heterosc = FALSE)


###################################################
### chunk number 50: 
###################################################
lrtest(hl.MC)
waldtest(hl.MC)


###################################################
### chunk number 51: 
###################################################
library("car")
linearHypothesis(hl.MC, c('sp.air=1', 'sp.train=1'))


###################################################
### chunk number 52: 
###################################################
scoretest(ml.MC, heterosc = TRUE)


###################################################
### chunk number 53: 
###################################################
c(wald = waldtest(hl.TM)$statistic, 
  lr = lrtest(hl.TM)$Chisq[2],
  score = scoretest(ml.TM, heterosc = TRUE)$statistic)


###################################################
### chunk number 54: 
###################################################
lrtest(nl.HC)
waldtest(nl.HC)
scoretest(ml.HC, nests = list(cooling = c('ecc', 'erc', 'gcc', 'hpc'), 
                   noncool = c('ec', 'gc', 'er')))


###################################################
### chunk number 55: 
###################################################
linearHypothesis(nl.HC, c("iv.cooling=1", "iv.noncool=1"))


###################################################
### chunk number 56: 
###################################################
lrtest(nl.HC,nl.HC.u)
waldtest(nl.HC, un.nest.el = TRUE)
scoretest(nl.HC.u, un.nest.el = FALSE)
linearHypothesis(nl.HC, "iv.cooling=iv.noncool")


###################################################
### chunk number 57: 
###################################################
lrtest(Train.mxlu, Train.ml)
waldtest(Train.mxlu)
scoretest(Train.ml, rpar = c(time = "n", change = "n", comfort = "n"), R = 100,     
          correlation = FALSE, halton = NA, panel = TRUE)


###################################################
### chunk number 58: 
###################################################
lrtest(Train.mxlc, Train.ml)
waldtest(Train.mxlc)
scoretest(Train.ml, rpar = c(time = "n", change = "n", comfort = "n"), R = 100,     
          correlation = TRUE, halton = NA, panel = TRUE)


###################################################
### chunk number 59: 
###################################################
lrtest(Train.mxlc, Train.mxlu)
waldtest(Train.mxlc, correlation = FALSE)
scoretest(Train.mxlu, correlation = TRUE)


